Welcome to elasticsearch Documentation!
=======================================

.. toctree::
  :maxdepth: 2
  :caption: Contents:

  all.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
